@@ -427,10 +427,11 @@ void KMZMap::draw(QPainter *painter, const QRectF &rect, Flags flags)
 }
 
 void KMZMap::load(const Projection &in, const Projection &out,
-  qreal deviceRatio, bool hidpi, int layer)
+  qreal deviceRatio, bool hidpi, int style, int layer)
 {
 	Q_UNUSED(out);
 	Q_UNUSED(layer);
+	Q_UNUSED(style);
 
 	_projection = in;
 	_mapRatio = hidpi ? deviceRatio : 1.0;
